@@ -320,8 +320,20 @@ class MyWhatify:
     ###        Gettrs         ###
     #############################
     @classmethod
-    def get_api_post(cls, url, user_token=None):
-        return APIRequestor().post(url=url, api_key=user_token)
+    def api_get(cls, url, headers=None, body=None, params=None, user_token=None):
+        return APIRequestor().get(url=url, headers=headers, body=body, params=params, api_key=user_token)
+
+    @classmethod
+    def api_post(cls, url, headers=None, body=None, params=None, user_token=None):
+        return APIRequestor().post(url=url, headers=headers, body=body, params=params, api_key=user_token)
+
+    @classmethod
+    def api_put(cls, url, headers=None, body=None, params=None, user_token=None):
+        return APIRequestor().put(url=url, headers=headers, body=body, params=params, api_key=user_token)
+
+    @classmethod
+    def api_patch(cls, url, headers=None, body=None, params=None, user_token=None):
+        return APIRequestor().patch(url=url, headers=headers, body=body, params=params, api_key=user_token)
 
     @classmethod
     def get_data_source(cls, data_name):
